package com.srs.routine.service;

import java.util.List;

import com.baomidou.mybatisplus.extension.service.IService;
import com.srs.routine.domain.RtStuQuitSchool;

/**
 * 休学申请记录Service接口
 *
 * @author LSD
 * @date 2024-06-12
 */
public interface IRtStuQuitSchoolService extends IService<RtStuQuitSchool> {
    /**
     * 查询休学申请记录
     *
     * @param quitSchoolId 休学申请记录主键
     * @return 休学申请记录
     */
    public RtStuQuitSchool selectRtStuQuitSchoolByQuitSchoolId(Long quitSchoolId);

    /**
     * 查询休学申请记录列表
     *
     * @param rtStuQuitSchool 休学申请记录
     * @return 休学申请记录集合
     */
    List<RtStuQuitSchool> selectRtStuQuitSchoolList(RtStuQuitSchool rtStuQuitSchool);

    /**
     * 新增休学申请记录
     *
     * @param rtStuQuitSchool 休学申请记录
     * @return 结果
     */
    int insertRtStuQuitSchool(RtStuQuitSchool rtStuQuitSchool);

    /**
     * 修改休学申请记录
     *
     * @param rtStuQuitSchool 休学申请记录
     * @return 结果
     */
    int updateRtStuQuitSchool(RtStuQuitSchool rtStuQuitSchool);

    /**
     * 批量删除休学申请记录
     *
     * @param quitSchoolIds 需要删除的休学申请记录主键集合
     * @return 结果
     */
    int deleteRtStuQuitSchoolByQuitSchoolIds(Long[] quitSchoolIds);

    /**
     * 删除休学申请记录信息
     *
     * @param quitSchoolId 休学申请记录主键
     * @return 结果
     */
    int deleteRtStuQuitSchoolByQuitSchoolId(Long quitSchoolId);

    /**
     * 根据流程id获取数据
     * @param procInsId
     * @return
     */
    RtStuQuitSchool getRtStuQuitSchoolByProcInsId(String procInsId);

    /**
     * 根据学务获取数据
     * @param rtStuQuitSchool
     * @return
     */
    List<RtStuQuitSchool> selectRtStuQuitSchoolListByXW(RtStuQuitSchool rtStuQuitSchool);

    /**
     * 根据辅导员获取数据
     * @param rtStuQuitSchool
     * @return
     */
    List<RtStuQuitSchool> selectRtStuQuitSchoolListByFdy(RtStuQuitSchool rtStuQuitSchool);

    /**
     * 修改
     * @param rtStuQuitSchool
     * @return
     */
    int editRtStuQuitSchool(RtStuQuitSchool rtStuQuitSchool);
}
